# =====================================
# generator=datazen
# version=3.1.4
# hash=302dd11b12a573508cf3316546a384ef
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "An interface generator for distributed computing."
PKG_NAME = "ifgen"
VERSION = "3.2.1"
